# Contributing

Your contribution is welcome! Please follow the [pull request workflow](https://guides.github.com/introduction/flow/), even for minor changes.

When contributing to this repository with a major change, please first discuss the change you wish to make via issue, email, or any other method with the owners of this repository.

Please note we have a [code of conduct](https://github.com/romainsacchi/carculator/blob/master/CODE_OF_CONDUCT.md), please follow it in all your interactions with the project.

## Documentation and coding standards

* [Black formatting](https://black.readthedocs.io/en/stable/)
* [Sphinx docstrings](https://sphinx-rtd-tutorial.readthedocs.io/en/latest/docstrings.html)
* [Semantic versioning](http://semver.org/)
* Data should be in text formats, e.g. JSON or CSV

## Authors

* [Romain Sacchi](https://github.com/romainsacchi)
* Your name here!
